#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-hedgehog
version:              1.4.0.2
visibility:           public
id:                   tasty-hedgehog-1.4.0.2-J053L2RzziD6WaD5oCjkXH
key:                  tasty-hedgehog-1.4.0.2-J053L2RzziD6WaD5oCjkXH
license:              BSD-3-Clause
copyright:
    Copyright (c) 2017, Commonwealth Scientific and Industrial Research Organisation (CSIRO) ABN 41 687 119 230.

maintainer:           dave.laing.80@gmail.com
author:               Dave Laing
homepage:             https://github.com/qfpl/tasty-hedgehog
synopsis:             Integration for tasty and hedgehog.
description:
    Integrates the <https://hackage.haskell.org/package/hedgehog hedgehog testing library> with the <https://hackage.haskell.org/package/tasty tasty testing framework>.

category:             Testing
abi:                  21def43ea70a60f1773c1267ccff3f00
exposed:              True
exposed-modules:      Test.Tasty.Hedgehog
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-hedgehog-1.4.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-hedgehog-1.4.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-hedgehog-1.4.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hedgehog
hs-libraries:         HStasty-hedgehog-1.4.0.2-J053L2RzziD6WaD5oCjkXH
depends:
    base-4.18.2.1 hedgehog-1.5-EAuCy8SHpthFxl2IPdPzBH
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig
    tasty-1.5.2-Ecucfh1EfNvF5aNYdx3wDU

haddock-interfaces:
    /usr/share/doc/haskell-tasty-hedgehog/html/tasty-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-tasty-hedgehog/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

